pub enum ValueOf {
BoolValue(bool),
StringValue(String),
BytesValue(Vec<u8>),
UuidValue(Uuid),
NumberValue(Number),
DateTimeValue(DateTime),
DateValue(Date),
DateRangeValue(DateRange),
ArrayValues(ArrayValue),
}Variants
BoolValue(bool)
StringValue(String)
BytesValue(Vec<u8>)
byte
UuidValue(Uuid)
uuid
NumberValue(Number)
DateTimeValue(DateTime)
DateValue(Date)
DateRangeValue(DateRange)
ArrayValues(ArrayValue)
Implementations
Sourceimpl ValueOf
impl ValueOf
Sourcepub fn merge(
field: &mut Option<ValueOf>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ValueOf>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.